You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@couchdb.apache.org by ja...@apache.org on 2016/04/25 13:53:29 UTC

[1/9] couchdb commit: updated refs/heads/test4th to 01edf89

Repository: couchdb
Updated Branches:
  refs/heads/test4th [created] 01edf892e


Bring multi key design test back


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/6c4f3d9a
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/6c4f3d9a
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/6c4f3d9a

Branch: refs/heads/test4th
Commit: 6c4f3d9a841cc0f10c2235eb807461eda9497a6d
Parents: 0eac44c
Author: sebastianro <se...@apache.org>
Authored: Fri Apr 15 18:37:35 2016 +0200
Committer: sebastianro <se...@apache.org>
Committed: Sat Apr 23 19:22:36 2016 +0200

----------------------------------------------------------------------
 test/javascript/tests/view_multi_key_design.js | 60 ++++++++++++---------
 1 file changed, 35 insertions(+), 25 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/6c4f3d9a/test/javascript/tests/view_multi_key_design.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/view_multi_key_design.js b/test/javascript/tests/view_multi_key_design.js
index 12be7b5..a50d1fb 100644
--- a/test/javascript/tests/view_multi_key_design.js
+++ b/test/javascript/tests/view_multi_key_design.js
@@ -11,7 +11,6 @@
 // the License.
 
 couchTests.view_multi_key_design = function(debug) {
-  return console.log('TODO');
   var db_name = get_random_db_name();
   var db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
   db.createDb();
@@ -155,69 +154,80 @@ couchTests.view_multi_key_design = function(debug) {
   // Check offset works
   curr = db.view("test/multi_emit", {skip: 1}, [0]).rows;
   T(curr.length == 99);
-  T(curr[0].value == 1);
+  // values are arbitrary as too many keys are the same
+  //T(curr[0].value == 1);
 
   curr = db.view("test/multi_emit", {skip: 1, keys: [0]}, null).rows;
   T(curr.length == 99);
-  T(curr[0].value == 1);
+  // values are arbitrary as too many keys are the same
+  //T(curr[0].value == 1);
 
   // Check that dir works
   curr = db.view("test/multi_emit", {descending: "true"}, [1]).rows;
   T(curr.length == 100);
-  T(curr[0].value == 99);
-  T(curr[99].value == 0);
+  // values are arbitrary as too many keys are the same
+  //T(curr[0].value == 99);
+  //T(curr[99].value == 0);
 
   curr = db.view("test/multi_emit", {descending: "true", keys: [1]}, null).rows;
   T(curr.length == 100);
-  T(curr[0].value == 99);
-  T(curr[99].value == 0);
+  // values are arbitrary as too many keys are the same
+  //T(curr[0].value == 99);
+  //T(curr[99].value == 0);
 
   // Check a couple combinations
   curr = db.view("test/multi_emit", {descending: "true", skip: 3, limit: 2}, [2]).rows;
   T(curr.length, 2);
-  T(curr[0].value == 96);
-  T(curr[1].value == 95);
+  // values are arbitrary as too many keys are the same
+  //T(curr[0].value == 96);
+  //T(curr[1].value == 95);
 
   curr = db.view("test/multi_emit", {descending: "true", skip: 3, limit: 2, keys: [2]}, null).rows;
   T(curr.length, 2);
-  T(curr[0].value == 96);
-  T(curr[1].value == 95);
+  // values are arbitrary as too many keys are the same
+  //T(curr[0].value == 96);
+  //T(curr[1].value == 95);
 
+  curr = db.view("test/multi_emit", {skip: 0, limit: 1, startkey_docid: "13"}, [0]).rows;
+  // that's the maximum we can get
+  T(curr.length == 1);
+  T(curr[0].value == 13);
+  
   curr = db.view("test/multi_emit", {skip: 2, limit: 3, startkey_docid: "13"}, [0]).rows;
   T(curr.length == 3);
-  T(curr[0].value == 15);
-  T(curr[1].value == 16);
-  T(curr[2].value == 17);
+  // values are arbitrary as too many keys are the same
+  //T(curr[0].value == 15);
+  //T(curr[1].value == 16);
+  //T(curr[2].value == 17);
 
   curr = db.view("test/multi_emit", {skip: 2, limit: 3, startkey_docid: "13", keys: [0]}, null).rows;
   T(curr.length == 3);
-  T(curr[0].value == 15);
-  T(curr[1].value == 16);
-  T(curr[2].value == 17);
+  // values are arbitrary as too many keys are the same
+  //T(curr[0].value == 15);
+  //T(curr[1].value == 16);
+  //T(curr[2].value == 17);
 
   curr = db.view("test/multi_emit",
           {skip: 1, limit: 5, startkey_docid: "25", endkey_docid: "27"}, [1]).rows;
   T(curr.length == 2);
-  T(curr[0].value == 26);
-  T(curr[1].value == 27);
+  // that's again the maximum we can get
+  T(curr[0].value == 26 || curr[0].value == 27);
 
   curr = db.view("test/multi_emit",
           {skip: 1, limit: 5, startkey_docid: "25", endkey_docid: "27", keys: [1]}, null).rows;
   T(curr.length == 2);
-  T(curr[0].value == 26);
-  T(curr[1].value == 27);
+  // that's again the maximum we can get
+  T(curr[0].value == 26 || curr[0].value == 27);
 
   curr = db.view("test/multi_emit",
           {skip: 1, limit: 5, startkey_docid: "28", endkey_docid: "26", descending: "true"}, [1]).rows;
   T(curr.length == 2);
-  T(curr[0].value == 27);
-  T(curr[1].value == 26);
+  // that's again the maximum we can get
+  T(curr[0].value == 26 || curr[0].value == 27);
 
   curr = db.view("test/multi_emit",
           {skip: 1, limit: 5, startkey_docid: "28", endkey_docid: "26", descending: "true", keys: [1]}, null).rows;
   T(curr.length == 2);
-  T(curr[0].value == 27);
-  T(curr[1].value == 26);
 
   // cleanup
   db.deleteDb();


[5/9] couchdb commit: updated refs/heads/test4th to 01edf89

Posted by ja...@apache.org.
Make reader_acl more stable


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/334eeee0
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/334eeee0
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/334eeee0

Branch: refs/heads/test4th
Commit: 334eeee08d156c5f6c416161d9d13a60bc5c20c4
Parents: a87ac58
Author: sebastianro <se...@apache.org>
Authored: Thu Apr 21 18:57:56 2016 +0200
Committer: sebastianro <se...@apache.org>
Committed: Sat Apr 23 19:23:43 2016 +0200

----------------------------------------------------------------------
 test/javascript/tests/reader_acl.js | 10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/334eeee0/test/javascript/tests/reader_acl.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/reader_acl.js b/test/javascript/tests/reader_acl.js
index 876446e..df390ca 100644
--- a/test/javascript/tests/reader_acl.js
+++ b/test/javascript/tests/reader_acl.js
@@ -87,7 +87,10 @@ couchTests.reader_acl = function(debug) {
       T(CouchDB.login("jchris@apache.org", "funnybone").ok);
 
       // db admin can read
-      T(secretDb.open("baz").foo == "bar");
+      // retry as propagation could take time
+      retry_part(function(){
+        T(secretDb.open("baz").foo == "bar");
+      });
 
       // and run temp views - they don't exist any more, so leave out 
       /*TEquals(secretDb.query(function(doc) {
@@ -160,7 +163,10 @@ couchTests.reader_acl = function(debug) {
 
       T(CouchDB.login("jchris@apache.org", "funnybone").ok);
       T(CouchDB.session().userCtx.roles.indexOf("_admin") == -1);
-      T(secretDb.open("baz").foo == "bar");
+      // retry as propagation could take time
+      retry_part(function(){
+        T(secretDb.open("baz").foo == "bar");
+      });
 
       // can't set non string reader names or roles
       try {


[8/9] couchdb commit: updated refs/heads/test4th to 01edf89

Posted by ja...@apache.org.
Test non-conflicting user doc


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/7bb5a810
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/7bb5a810
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/7bb5a810

Branch: refs/heads/test4th
Commit: 7bb5a8109ad913b9eb4652b0f55fbe83c83e4bf3
Parents: 1ae2c75
Author: sebastianro <se...@apache.org>
Authored: Sun Apr 24 13:27:19 2016 +0200
Committer: sebastianro <se...@apache.org>
Committed: Sun Apr 24 13:27:19 2016 +0200

----------------------------------------------------------------------
 test/javascript/tests/users_db.js | 44 +++++++++++++++++++++-------------
 1 file changed, 27 insertions(+), 17 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/7bb5a810/test/javascript/tests/users_db.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/bulk_docs.js b/test/javascript/tests/bulk_docs.js
index 7fc93fd..b9e9716 100644
--- a/test/javascript/tests/bulk_docs.js
+++ b/test/javascript/tests/bulk_docs.js
@@ -11,7 +11,7 @@
 // the License.
 
 couchTests.bulk_docs = function(debug) {
-  var db_name = get_random_db_name()
+  var db_name = get_random_db_name();
   var db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
   db.createDb();
   if (debug) debugger;
@@ -112,6 +112,9 @@ couchTests.bulk_docs = function(debug) {
 
   // jira-911
   db.deleteDb();
+  // avoid Heisenbugs w/ files remaining - create a new name
+  db_name = get_random_db_name();
+  db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
   db.createDb();
   docs = [];
   docs.push({"_id":"0", "a" : 0});

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/design_docs.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/design_docs.js b/test/javascript/tests/design_docs.js
index 6c46437..ab62f3f 100644
--- a/test/javascript/tests/design_docs.js
+++ b/test/javascript/tests/design_docs.js
@@ -428,6 +428,9 @@ couchTests.design_docs = function(debug) {
   // field with the boolean value true, its validate_doc_update functions
   // should no longer have effect.
   db.deleteDb();
+  // avoid Heisenbugs w/ files remaining - create a new name
+  db_name = get_random_db_name();
+  db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
   db.createDb();
   var ddoc = {
     _id: "_design/test",

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/etags_views.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/etags_views.js b/test/javascript/tests/etags_views.js
index bed98ed..6c110f8 100644
--- a/test/javascript/tests/etags_views.js
+++ b/test/javascript/tests/etags_views.js
@@ -204,12 +204,12 @@ couchTests.etags_views = function(debug) {
   
   // A new database should have unique _all_docs etags. 
   db.deleteDb(); 
-  db.createDb(); 
+  db.createDb(); // TODO: when re-activating try having a new DB name
   db.save({a: 1}); 
   xhr = CouchDB.request("GET", "/" + db_name + "/_all_docs"); 
   var etag = xhr.getResponseHeader("etag"); 
   db.deleteDb(); 
-  db.createDb(); 
+  db.createDb(); // TODO: when re-activating try having a new DB name
   db.save({a: 2}); 
   xhr = CouchDB.request("GET", "/" + db_name + "/_all_docs"); 
   var new_etag = xhr.getResponseHeader("etag");

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/reader_acl.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/reader_acl.js b/test/javascript/tests/reader_acl.js
index a76f280..876446e 100644
--- a/test/javascript/tests/reader_acl.js
+++ b/test/javascript/tests/reader_acl.js
@@ -113,10 +113,10 @@ couchTests.reader_acl = function(debug) {
       // server _admin can always read
       T(secretDb.open("baz").foo == "bar");
 
-      // and run temp views
-      TEquals(secretDb.query(function(doc) {
+      // and run temp views - they don't exist any more, so leave out
+      /*TEquals(secretDb.query(function(doc) {
         emit(null, null)
-      }).total_rows, 1);
+      }).total_rows, 1);*/
 
       T(secretDb.save({
         "_id" : "_design/foo",
@@ -134,15 +134,15 @@ couchTests.reader_acl = function(debug) {
       // members can query stored views
       T(secretDb.view("foo/bar").total_rows == 1);
       
-      // members can't do temp views
-      try {
+      // members can't do temp views - they don't exist any more, so leave out
+      /*try {
         var results = secretDb.query(function(doc) {
           emit(null, null);
         });
         T(false && "temp view should be admin only");
       } catch (e) {
         T(true && "temp view is admin only");
-      }
+      }*/
       
       CouchDB.logout();
 

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/recreate_doc.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/recreate_doc.js b/test/javascript/tests/recreate_doc.js
index ea7916f..154a6e4 100644
--- a/test/javascript/tests/recreate_doc.js
+++ b/test/javascript/tests/recreate_doc.js
@@ -79,6 +79,9 @@ couchTests.recreate_doc = function(debug) {
   }
 
   db.deleteDb();
+  // avoid Heisenbugs - have a new name
+  db_name = get_random_db_name();
+  db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"}, {"w": 3});
   db.createDb();
 
   // Helper function to create a doc with multiple revisions

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/replication.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/replication.js b/test/javascript/tests/replication.js
index 1a26889..b758b4f 100644
--- a/test/javascript/tests/replication.js
+++ b/test/javascript/tests/replication.js
@@ -15,25 +15,27 @@ couchTests.replication = function(debug) {
   if (debug) debugger;
 
   var host = CouchDB.host;
-  var sourceDb = new CouchDB("test_suite_db_a",{"X-Couch-Full-Commit":"false"});
-  var targetDb = new CouchDB("test_suite_db_b",{"X-Couch-Full-Commit":"false"});
+  // as we change names during execution, do NOT use test_suite_db or a 
+  // pre-computed value like ''+sourceDb.name (compute only on use)
+  var sourceDb;
+  var targetDb;
 
-  var dbPairs = [
+  var dbPairsPrefixes = [
     {
-      source: sourceDb.name,
-      target: targetDb.name
+      source: "",
+      target: ""
     },
     {
-      source: CouchDB.protocol + host + "/" + sourceDb.name,
-      target: targetDb.name
+      source: CouchDB.protocol + host + "/",
+      target: ""
     },
     {
-      source: sourceDb.name,
-      target: CouchDB.protocol + host + "/" + targetDb.name
+      source: "",
+      target: CouchDB.protocol + host + "/"
     },
     {
-      source: CouchDB.protocol + host + "/" + sourceDb.name,
-      target: CouchDB.protocol + host + "/" + targetDb.name
+      source: CouchDB.protocol + host + "/",
+      target: CouchDB.protocol + host + "/"
     }
   ];
 
@@ -124,17 +126,36 @@ couchTests.replication = function(debug) {
   }
 
 
-  function populateDb(db, docs, dontRecreateDb) {
-    if (dontRecreateDb !== true) {
-      db.deleteDb();
-      db.createDb();
+  function populateSourceDb(docs, dontRecreateDb) {
+    if(dontRecreateDb !== true) {
+      if(sourceDb) {
+        sourceDb.deleteDb();
+      }
+      sourceDb = new CouchDB(get_random_db_name() + "_src",{"X-Couch-Full-Commit":"false"});
+      sourceDb.createDb(); 
+    }
+    for (var i = 0; i < docs.length; i++) {
+      var doc = docs[i];
+      delete doc._rev;
+    }
+    if (docs.length > 0) {
+      sourceDb.bulkSave(docs);
+    }
+  }
+  function populateTargetDb(docs, dontRecreateDb) {
+    if(dontRecreateDb !== true) {
+      if(targetDb) {
+        targetDb.deleteDb();
+      }
+      targetDb = new CouchDB(get_random_db_name() + "_tgt",{"X-Couch-Full-Commit":"false"});
+      targetDb.createDb();
     }
     for (var i = 0; i < docs.length; i++) {
       var doc = docs[i];
       delete doc._rev;
     }
     if (docs.length > 0) {
-      db.bulkSave(docs);
+      targetDb.bulkSave(docs);
     }
   }
 
@@ -221,16 +242,16 @@ couchTests.replication = function(debug) {
     value: "ddoc"
   });
 
-  for (i = 0; i < dbPairs.length; i++) {
-    populateDb(sourceDb, docs);
-    populateDb(targetDb, []);
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
+    populateSourceDb(docs);
+    populateTargetDb([]);
 
     // add some attachments
     for (j = 10; j < 15; j++) {
       addAtt(sourceDb, docs[j], "readme.txt", att1_data, "text/plain");
     }
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
 
     sourceInfo = sourceDb.info();
@@ -293,7 +314,7 @@ couchTests.replication = function(debug) {
       addAtt(sourceDb, docs[j], "data.dat", att2_data, "application/binary");
     }
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
 
     sourceInfo = sourceDb.info();
@@ -360,7 +381,7 @@ couchTests.replication = function(debug) {
     doc = sourceDb.open(docs[1]._id);
     TEquals(true, sourceDb.deleteDoc(doc).ok);
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
 
     sourceInfo = sourceDb.info();
@@ -403,7 +424,7 @@ couchTests.replication = function(debug) {
     copy.value = "black";
     TEquals(true, targetDb.save(copy).ok);
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
 
     sourceInfo = sourceDb.info();
@@ -434,7 +455,7 @@ couchTests.replication = function(debug) {
     doc.value = "yellow";
     TEquals(true, sourceDb.save(doc).ok);
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
 
     sourceInfo = sourceDb.info();
@@ -468,7 +489,7 @@ couchTests.replication = function(debug) {
     doc.value = "rainbow";
     TEquals(true, sourceDb.save(doc).ok);
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
 
     sourceInfo = sourceDb.info();
@@ -500,7 +521,7 @@ couchTests.replication = function(debug) {
     TEquals(true, sourceDb.save({_id: "foo3", value: 333}).ok);
     TEquals(true, targetDb.save({_id: "foo3", value: 333}).ok);
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
 
     sourceInfo = sourceDb.info();
@@ -520,7 +541,7 @@ couchTests.replication = function(debug) {
     TEquals(true, sourceDb.save({_id: "foo5", value: 555}).ok);
     TEquals(true, targetDb.save({_id: "foo5", value: 555}).ok);
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
 
     sourceInfo = sourceDb.info();
@@ -535,7 +556,7 @@ couchTests.replication = function(debug) {
     TEquals(0, repResult.history[0].docs_written);
     TEquals(0, repResult.history[0].doc_write_failures);
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
     TEquals(true, repResult.no_changes);
     sourceInfo = sourceDb.info();
@@ -571,9 +592,9 @@ couchTests.replication = function(debug) {
   // test since_seq parameter
   docs = makeDocs(1, 6);
 
-  for (i = 0; i < dbPairs.length; i++) {
-    populateDb(sourceDb, docs);
-    populateDb(targetDb, []);
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
+    populateSourceDb(docs);
+    populateTargetDb([]);
     // sequences are no longer simple numbers - so pull #3 from a feed
     var since_seq = sourceDb.changes().results[2].seq;
 
@@ -590,8 +611,8 @@ couchTests.replication = function(debug) {
     // effect.
     try {
       CouchDB.replicate(
-        dbPairs[i].source,
-        dbPairs[i].target,
+        dbPairsPrefixes[i].source+sourceDb.name,
+        dbPairsPrefixes[i].target+targetDb.name,
         {body: {cancel: true}}
       );
     } catch (x) {
@@ -599,8 +620,8 @@ couchTests.replication = function(debug) {
       TEquals("not_found", x.error);
     }
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target,
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name,
       {body: {since_seq: since_seq}}
     );
     // Same reason as before. But here we don't want since_seq to affect
@@ -608,8 +629,8 @@ couchTests.replication = function(debug) {
     // supervisor (since_seq is not used to calculate the replication ID).
     try {
       CouchDB.replicate(
-        dbPairs[i].source,
-        dbPairs[i].target,
+        dbPairsPrefixes[i].source+sourceDb.name,
+        dbPairsPrefixes[i].target+targetDb.name,
         {body: {cancel: true}}
       );
     } catch (x) {
@@ -655,13 +676,13 @@ couchTests.replication = function(debug) {
     }).toString()
   };
 
-  for (i = 0; i < dbPairs.length; i++) {
-    populateDb(sourceDb, docs);
-    populateDb(targetDb, [ddoc]);
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
+    populateSourceDb(docs);
+    populateTargetDb([ddoc]);
 
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name
     );
     TEquals(true, repResult.ok);
     TEquals(7, repResult.history[0].missing_checked);
@@ -687,13 +708,13 @@ couchTests.replication = function(debug) {
   // test create_target option
   docs = makeDocs(1, 2);
 
-  for (i = 0; i < dbPairs.length; i++) {
-    populateDb(sourceDb, docs);
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
+    populateSourceDb(docs);
     targetDb.deleteDb();
 
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target,
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name,
       {body: {create_target: true}}
     );
     TEquals(true, repResult.ok);
@@ -720,13 +741,13 @@ couchTests.replication = function(debug) {
     }
   });
 
-  for (i = 0; i < dbPairs.length; i++) {
-    populateDb(sourceDb, docs);
-    populateDb(targetDb, []);
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
+    populateSourceDb(docs);
+    populateTargetDb([]);
 
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target,
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name,
       {
         body: {
           filter: "mydesign/myfilter",
@@ -787,11 +808,11 @@ couchTests.replication = function(debug) {
 
     // add new docs to source and resume the same replication
     var newDocs = makeDocs(50, 56);
-    populateDb(sourceDb, newDocs, true);
+    populateSourceDb(newDocs, true);
 
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target,
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name,
       {
         body: {
           filter: "mydesign/myfilter",
@@ -848,9 +869,9 @@ couchTests.replication = function(debug) {
     return true;
   }).toString();
 
-  for (i = 0; i < dbPairs.length; i++) {
-    populateDb(targetDb, []);
-    populateDb(sourceDb, []);
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
+    populateTargetDb([]);
+    populateSourceDb([]);
 
     TEquals(true, sourceDb.save({_id: "foo1", value: 1}).ok);
     TEquals(true, sourceDb.save({_id: "foo2", value: 2}).ok);
@@ -868,8 +889,8 @@ couchTests.replication = function(debug) {
     TEquals(true, sourceDb.save(ddoc).ok);
 
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target,
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name,
       {
         body: {
           filter: "mydesign/myfilter",
@@ -907,8 +928,8 @@ couchTests.replication = function(debug) {
     TEquals(true, sourceDb.save(ddoc).ok);
 
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target,
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name,
       {
         body: {
           filter: "mydesign/myfilter",
@@ -966,7 +987,7 @@ couchTests.replication = function(debug) {
   var id, num_inexistent_docs, after_num_inexistent_docs;
   var total, after_total;
 
-  for (i = 0; i < dbPairs.length; i++) {
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
 
     for (j = 0; j < target_doc_ids.length; j++) {
       doc_ids = target_doc_ids[j].initial;
@@ -979,12 +1000,12 @@ couchTests.replication = function(debug) {
         }
       }
 
-      populateDb(sourceDb, docs);
-      populateDb(targetDb, []);
+      populateSourceDb(docs);
+      populateTargetDb([]);
 
       repResult = CouchDB.replicate(
-        dbPairs[i].source,
-        dbPairs[i].target,
+        dbPairsPrefixes[i].source+sourceDb.name,
+        dbPairsPrefixes[i].target+targetDb.name,
         {
           body: {
             doc_ids: doc_ids
@@ -1048,8 +1069,8 @@ couchTests.replication = function(debug) {
       }
 
       repResult = CouchDB.replicate(
-        dbPairs[i].source,
-        dbPairs[i].target,
+        dbPairsPrefixes[i].source+sourceDb.name,
+        dbPairsPrefixes[i].target+targetDb.name,
         {
           body: {
             doc_ids: after_doc_ids
@@ -1113,8 +1134,8 @@ couchTests.replication = function(debug) {
       addAtt(sourceDb, doc, "data.dat", att2_data, "application/binary");
 
       repResult = CouchDB.replicate(
-        dbPairs[i].source,
-        dbPairs[i].target,
+        dbPairsPrefixes[i].source+sourceDb.name,
+        dbPairsPrefixes[i].target+targetDb.name,
         {
           body: {
             doc_ids: [id]
@@ -1170,8 +1191,8 @@ couchTests.replication = function(debug) {
       TEquals(true, targetDb.save(copy).ok);
 
       repResult = CouchDB.replicate(
-        dbPairs[i].source,
-        dbPairs[i].target,
+        dbPairsPrefixes[i].source+sourceDb.name,
+        dbPairsPrefixes[i].target+targetDb.name,
         {
           body: {
             doc_ids: [id]
@@ -1203,9 +1224,9 @@ couchTests.replication = function(debug) {
     }
   });
 
-  for (i = 0; i < dbPairs.length; i++) {
-    populateDb(sourceDb, docs);
-    populateDb(targetDb, []);
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
+    populateSourceDb(docs);
+    populateTargetDb([]);
 
     // add some attachments
     for (j = 10; j < 15; j++) {
@@ -1213,8 +1234,8 @@ couchTests.replication = function(debug) {
     }
 
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target,
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name,
       {
         body: {
           continuous: true
@@ -1344,7 +1365,7 @@ couchTests.replication = function(debug) {
 
     // add more docs to source
     var newDocs = makeDocs(25, 35);
-    populateDb(sourceDb, newDocs, true);
+    populateSourceDb(newDocs, true);
 
     waitForSeq(sourceDb, targetDb, rep_id);
 
@@ -1383,8 +1404,8 @@ couchTests.replication = function(debug) {
 
     // cancel the replication
     repResult = CouchDB.replicate(
-      dbPairs[i].source,
-      dbPairs[i].target,
+      dbPairsPrefixes[i].source+sourceDb.name,
+      dbPairsPrefixes[i].target+targetDb.name,
       {
         body: {
           continuous: true,
@@ -1418,8 +1439,8 @@ couchTests.replication = function(debug) {
       myfilter: (function(doc, req) { return true; }).toString()
     }
   });
-  populateDb(sourceDb, docs);
-  populateDb(targetDb, []);
+  populateSourceDb(docs);
+  populateTargetDb([]);
 
   repResult = CouchDB.replicate(
     CouchDB.protocol + host + "/" + sourceDb.name,
@@ -1473,9 +1494,9 @@ couchTests.replication = function(debug) {
   var compressionLevel = oldSettings.level;
   var compressibleTypes = oldSettings.types;
 
-  for (i = 0; i < dbPairs.length; i++) {
-    populateDb(sourceDb, [doc]);
-    populateDb(targetDb, []);
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
+    populateSourceDb([doc]);
+    populateTargetDb([]);
 
     // enable compression of text types
     enableAttCompression("8", "text/*");
@@ -1494,7 +1515,7 @@ couchTests.replication = function(debug) {
     // disable compression and replicate
     disableAttCompression();
 
-    repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+    repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
     TEquals(true, repResult.ok);
     TEquals(true, repResult.history instanceof Array);
     TEquals(1, repResult.history.length);
@@ -1545,29 +1566,29 @@ couchTests.replication = function(debug) {
     language: "javascript"
   });
 
-  dbPairs = [
+  dbPairsPrefixes = [
     {
-      source: sourceDb.name,
-      target: targetDb.name
+      source: "",
+      target: ""
     },
     {
-      source: CouchDB.protocol + host + "/" + sourceDb.name,
-      target: targetDb.name
+      source: CouchDB.protocol + host + "/",
+      target: ""
     },
     {
-      source: sourceDb.name,
-      target: CouchDB.protocol + "joe:erly@" + host + "/" + targetDb.name
+      source: "",
+      target: CouchDB.protocol + "joe:erly@" + host + "/"
     },
     {
-      source: CouchDB.protocol + host + "/" + sourceDb.name,
-      target: CouchDB.protocol + "joe:erly@" + host + "/" + targetDb.name
+      source: CouchDB.protocol + host + "/",
+      target: CouchDB.protocol + "joe:erly@" + host + "/"
     }
   ];
 
-  for (i = 0; i < dbPairs.length; i++) {
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
     //usersDb.deleteDb();
-    populateDb(sourceDb, docs);
-    populateDb(targetDb, []);
+    populateSourceDb(docs);
+    populateTargetDb([]);
 
     TEquals(true, targetDb.setSecObj({
       admins: {
@@ -1588,7 +1609,7 @@ couchTests.replication = function(debug) {
       TEquals(true, CouchDB.login("joe", "erly").ok);
       TEquals('joe', CouchDB.session().userCtx.name);
 
-      repResult = CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+      repResult = CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
 
       TEquals(true, CouchDB.logout().ok);
 
@@ -1612,29 +1633,29 @@ couchTests.replication = function(debug) {
   }
 
   // case 2) user triggering the replication is not a reader (nor admin) of the source DB
-  dbPairs = [
+  dbPairsPrefixes = [
     {
-      source: sourceDb.name,
-      target: targetDb.name
+      source: "",
+      target: ""
     },
     {
-      source: CouchDB.protocol + "joe:erly@" + host + "/" + sourceDb.name,
-      target: targetDb.name
+      source: CouchDB.protocol + "joe:erly@" + host + "/",
+      target: ""
     },
     {
-      source: sourceDb.name,
-      target: CouchDB.protocol + host + "/" + targetDb.name
+      source: "",
+      target: CouchDB.protocol + host + "/"
     },
     {
-      source: CouchDB.protocol + "joe:erly@" + host + "/" + sourceDb.name,
-      target: CouchDB.protocol + host + "/" + targetDb.name
+      source: CouchDB.protocol + "joe:erly@" + host + "/",
+      target: CouchDB.protocol + host + "/"
     }
   ];
 
-  for (i = 0; i < dbPairs.length; i++) {
+  for (i = 0; i < dbPairsPrefixes.length; i++) {
     //usersDb.deleteDb();
-    populateDb(sourceDb, docs);
-    populateDb(targetDb, []);
+    populateSourceDb(docs);
+    populateTargetDb([]);
 
     TEquals(true, sourceDb.setSecObj({
       admins: {
@@ -1666,7 +1687,7 @@ couchTests.replication = function(debug) {
       TEquals('joe', CouchDB.session().userCtx.name);
 
       try {
-        CouchDB.replicate(dbPairs[i].source, dbPairs[i].target);
+        CouchDB.replicate(dbPairsPrefixes[i].source+sourceDb.name, dbPairsPrefixes[i].target+targetDb.name);
         T(false, "should have raised an exception");
       } catch (x) {
         // TODO: small thing: DB exists but is no more found - at least we have an exception, so it's rather minor
@@ -1690,10 +1711,8 @@ couchTests.replication = function(debug) {
   sourceDb = new CouchDB("test_suite_db_a");
   targetDb = new CouchDB("test_suite_db_b");
 
-  sourceDb.deleteDb();
-  sourceDb.createDb();
-  targetDb.deleteDb();
-  targetDb.createDb();
+  populateSourceDb([]);
+  populateTargetDb([]);
 
   doc = {
     _id: "doc1"
@@ -1770,8 +1789,8 @@ couchTests.replication = function(debug) {
   // like  {"replication_id": Id, "cancel": true}. The replication ID
   // can be obtained from a continuous replication request response
   // (_local_id field), from _active_tasks or from the log
-  populateDb(sourceDb, makeDocs(1, 6));
-  populateDb(targetDb, []);
+  populateSourceDb(makeDocs(1, 6));
+  populateTargetDb([]);
 
   repResult = CouchDB.replicate(
     CouchDB.protocol + host + "/" + sourceDb.name,
@@ -1826,8 +1845,8 @@ couchTests.replication = function(debug) {
   ];*/
 
   //run_on_modified_server(server_config, function() {
-    populateDb(sourceDb, makeDocs(1, 6));
-    populateDb(targetDb, []);
+    populateSourceDb(makeDocs(1, 6));
+    populateTargetDb([]);
     var prevUserDoc = defaultUsersDb.open(userDoc._id);
     if(prevUserDoc) {
       userDoc._rev = prevUserDoc._rev;
@@ -1871,5 +1890,6 @@ couchTests.replication = function(debug) {
   //usersDb.deleteDb();
   sourceDb.deleteDb();
   targetDb.deleteDb();
+  // (not sure what this is - cleanup after 'file not found tests' poss. - not harmful anyway) 
   (new CouchDB("test_suite_db")).deleteDb();
 };

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/security_validation.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/security_validation.js b/test/javascript/tests/security_validation.js
index 5c50ff5..0bd9097 100644
--- a/test/javascript/tests/security_validation.js
+++ b/test/javascript/tests/security_validation.js
@@ -257,9 +257,10 @@ couchTests.security_validation = function(debug) {
       var A = CouchDB.protocol + CouchDB.host + "/" + db_name + "_a";
       var B = CouchDB.protocol + CouchDB.host + "/" + db_name + "_b";
 
-      adminDbA.deleteDb();
+      // (the databases never exist b4 - and we made sure they're deleted below)
+      //adminDbA.deleteDb();
       adminDbA.createDb();
-      adminDbB.deleteDb();
+      //adminDbB.deleteDb();
       adminDbB.createDb();
 
       // save and replicate a documents that will and will not pass our design

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/show_documents.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/show_documents.js b/test/javascript/tests/show_documents.js
index 82d66ae..ca75637 100644
--- a/test/javascript/tests/show_documents.js
+++ b/test/javascript/tests/show_documents.js
@@ -395,9 +395,13 @@ couchTests.show_documents = function(debug) {
   // (we don't need no modified server!)
   T(db.setDbProperty("_security", {foo: true}).ok);
   T(db.save({_id:"testdoc",foo:1}).ok);
-  xhr = CouchDB.request("GET", "/" + db_name + "/_design/template/_show/secObj");
-  var resp = JSON.parse(xhr.responseText);
-  T(resp.foo == true);
+  // nasty source of Heisenbugs - it replicates after a short time, so give it some tries
+  // (needs PR #400 and #401 to be merged)
+  retry_part(function(){
+    xhr = CouchDB.request("GET", "/" + db_name + "/_design/template/_show/secObj");
+    var resp = JSON.parse(xhr.responseText);
+    T(resp.foo == true);
+  }, 10);
 
   // cleanup
   db.deleteDb();

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/view_offsets.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/view_offsets.js b/test/javascript/tests/view_offsets.js
index 5b286c4..8b39cc2 100644
--- a/test/javascript/tests/view_offsets.js
+++ b/test/javascript/tests/view_offsets.js
@@ -60,8 +60,10 @@ couchTests.view_offsets = function(debug) {
   ].forEach(function(row){ check(row[0], row[1]);});
 
   var runTest = function () {
-    var db = new CouchDB("test_suite_db", {"X-Couch-Full-Commit":"false"});
-    db.deleteDb();
+    var db_name = get_random_db_name();
+    var db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
+    // (the DB will never exist per se)
+    //db.deleteDb();
     db.createDb();
 
     var designDoc = {
@@ -99,6 +101,9 @@ couchTests.view_offsets = function(debug) {
         endkey: ["b", 7]
     });
 
+    // delete (temp) DB now
+    db.deleteDb();
+
     return res1.offset == 4 && res2.offset == docs.length && res3.offset == 8;
 
   };

http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/view_sandboxing.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/view_sandboxing.js b/test/javascript/tests/view_sandboxing.js
index 2676e7f..c70eecc 100644
--- a/test/javascript/tests/view_sandboxing.js
+++ b/test/javascript/tests/view_sandboxing.js
@@ -99,6 +99,9 @@ couchTests.view_sandboxing = function(debug) {
   };
 
   db.deleteDb();
+  // avoid Heisenbugs when files are not cleared entirely
+  db_name = get_random_db_name();
+  db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
   db.createDb();
   T(db.save(ddoc).ok);
   T(db.save(doc1).ok);


[7/9] couchdb commit: updated refs/heads/test4th to 01edf89

Posted by ja...@apache.org.
Improve wait/retry


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/1ae2c75b
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/1ae2c75b
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/1ae2c75b

Branch: refs/heads/test4th
Commit: 1ae2c75bfc10e9fcca23ca995a7802414a39de39
Parents: 334eeee
Author: sebastianro <se...@apache.org>
Authored: Sat Apr 23 19:59:07 2016 +0200
Committer: sebastianro <se...@apache.org>
Committed: Sat Apr 23 19:59:07 2016 +0200

----------------------------------------------------------------------
 test/javascript/couch_test_runner.js | 8 +++++++-
 1 file changed, 7 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/1ae2c75b/test/javascript/couch_test_runner.js
----------------------------------------------------------------------
diff --git a/test/javascript/couch_test_runner.js b/test/javascript/couch_test_runner.js
index 1d53255..887e988 100644
--- a/test/javascript/couch_test_runner.js
+++ b/test/javascript/couch_test_runner.js
@@ -486,13 +486,19 @@ function get_random_db_name() {
 
 // for Heisenbug-prone spots: retry n times (e.g. quora not met immediately)
 // if the problem still persists afterwards, we need sth else (similar to e.g. webdriver)
-function retry_part(fct, n) {
+function retry_part(fct, n, duration) {
   n = n || 3;
+  duration = (duration == undefined ? 100 : duration);
   for(var i=1; i<=n; i++){
     try {
       return fct();
     }catch(e){
       if(i<n){
+        // wait
+        var b4 = (new Date()).getTime();
+        // if this is too bad, we could GET /
+        // or in fact get _changes w/ longpoll on _users or so
+        while(((new Date()).getTime() - b4) < duration) {}
         continue;
       }else{
         throw e;


[9/9] couchdb commit: updated refs/heads/test4th to 01edf89

Posted by ja...@apache.org.
different attempt at making users_db test go


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/01edf892
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/01edf892
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/01edf892

Branch: refs/heads/test4th
Commit: 01edf892e76d50d78d4c89eca25cada0a6c3e7b9
Parents: 7bb5a81
Author: Jan Lehnardt <ja...@apache.org>
Authored: Mon Apr 25 13:51:18 2016 +0200
Committer: Jan Lehnardt <ja...@apache.org>
Committed: Mon Apr 25 13:51:18 2016 +0200

----------------------------------------------------------------------
 test/javascript/run               |  1 +
 test/javascript/tests/users_db.js | 84 ++++++++++++++--------------------
 2 files changed, 36 insertions(+), 49 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/01edf892/test/javascript/run
----------------------------------------------------------------------
diff --git a/test/javascript/run b/test/javascript/run
index 806b7e7..ad8c718 100755
--- a/test/javascript/run
+++ b/test/javascript/run
@@ -35,6 +35,7 @@ SCRIPTS = """
     test/javascript/couch_test_runner.js
     test/javascript/couch_http.js
     test/javascript/test_setup.js
+    share/server/util.js
 """.split()
 
 RUNNER = "test/javascript/cli_runner.js"

http://git-wip-us.apache.org/repos/asf/couchdb/blob/01edf892/test/javascript/tests/users_db.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/users_db.js b/test/javascript/tests/users_db.js
index e59b398..ada0047 100644
--- a/test/javascript/tests/users_db.js
+++ b/test/javascript/tests/users_db.js
@@ -15,11 +15,8 @@ couchTests.users_db = function(debug) {
   // This tests the users db, especially validations
   // this should also test that you can log into the couch
   
-  var users_db_name = get_random_db_name();
+  var users_db_name = '_users'; //get_random_db_name();
   var usersDb = new CouchDB(users_db_name, {"X-Couch-Full-Commit":"false"});
-  usersDb.createDb();
-  var usersDbAlt = new CouchDB(users_db_name + "_alt", {"X-Couch-Full-Commit":"false"});
-  usersDbAlt.createDb();
 
   // test that you can treat "_user" as a db-name
   // this can complicate people who try to secure the users db with 
@@ -29,10 +26,14 @@ couchTests.users_db = function(debug) {
   // to determine the actual users db name.
 
   function testFun() {
+
     // test that the validation function is installed
+    // this will fail When the test is run in isolation,
+    // since it doesn’t wait for the ddoc to be created.
+    // in a full test suite run, this is fine.
+    // dev trick: run `test/javascript/run basics users_db`
     var ddoc = usersDb.open("_design/_auth");
-// TODO: validation ddoc does not get installed on cluster
-//  T(ddoc.validate_doc_update);
+    T(ddoc.validate_doc_update);
     
     // test that you can login as a user using basic auth
     var jchrisUserDoc = CouchDB.prepareUserDoc({
@@ -52,8 +53,7 @@ couchTests.users_db = function(debug) {
     T(s.userCtx.name == "jchris@apache.org");
     T(s.info.authenticated == "default");
     T(s.info.authentication_db == "" + users_db_name + "");
-    T(s.info.authentication_handlers.indexOf("cookie")>=0);
-    T(s.info.authentication_handlers.indexOf("default")>=0);
+    TEquals(["cookie", "default", "local"], s.info.authentication_handlers);
     var s = CouchDB.session({
       headers : {
         "Authorization" : "Basic Xzpf" // name and pass of _:_
@@ -61,52 +61,46 @@ couchTests.users_db = function(debug) {
     });
     T(s.name == null);
     T(s.info.authenticated == "default");
-
-    // make sure we'll not hit the cache with this
-    var kchrisUserDoc = CouchDB.prepareUserDoc({
-      name: "kchris@apache.org"
-    }, "sadbone");
-    T(usersDb.save(kchrisUserDoc).ok);
     
-    // save with new_edits=false to force conflict save does no more work => actually replicate and change simultanously
-    CouchDB.replicate(usersDb.name, usersDbAlt.name);
-    // ok, now create a conflicting edit on the kchris doc, and make sure there's no login.
-    var kchrisUser2 = JSON.parse(JSON.stringify(kchrisUserDoc));
-    kchrisUser2.foo = "bar";
-    T(usersDb.save(kchrisUser2).ok);
-    // now the other
-    var kchrisUser3 = JSON.parse(JSON.stringify(kchrisUserDoc));
-    kchrisUser3.foo = "barrrr";
-    T(usersDbAlt.save(kchrisUser3).ok);
-    // and replicate back
-    CouchDB.replicate(usersDbAlt.name, usersDb.name);
-
-    var kchrisWithConflict = usersDb.open(kchrisUserDoc._id, {conflicts : true, revs_info: true});
-    T(kchrisWithConflict._conflicts.length == 1);
     
+    // ok, now create a conflicting edit on the jchris doc, and make sure there's no login.
+    var jchrisUser2 = JSON.parse(JSON.stringify(jchrisUserDoc));
+    jchrisUser2.foo = "bar";
+    var r = usersDb.save(jchrisUser2)
+    T(r.ok);
+    try {
+      usersDb.save(jchrisUserDoc);
+      T(false && "should be an update conflict");
+    } catch(e) {
+      T(true);
+    }
+    // save as bulk with new_edits=false to force conflict save
+    jchrisUserDoc._rev = "1-asd" // set new rev, changed in 2.x!
+    var resp = usersDb.bulkSave([jchrisUserDoc],{new_edits: false});
+
+    var jchrisWithConflict = usersDb.open(jchrisUserDoc._id, {conflicts : true});
+    T(jchrisWithConflict._conflicts.length == 1);
+
     // no login with conflicted user doc
-    CouchDB.logout();
-    var s = null;
     try {
-      s = CouchDB.session({
+      var s = CouchDB.session({
         headers : {
-          "Authorization" : "Basic a2NocmlzQGFwYWNoZS5vcmc6ZnVubnlib25l"
+          "Authorization" : "Basic amNocmlzQGFwYWNoZS5vcmc6ZnVubnlib25l"
         }
       });
-    }catch(e){
-      // old test had name==null, now we might have an error. Anyway: test below
+      T(false && "this will throw");
+    } catch(e) {
+      T(e.error == "unauthorized");
+      T(/conflict/.test(e.reason));
     }
-    T(s == null || s.userCtx.name == null);
 
     // you can delete a user doc
     s = CouchDB.session().userCtx;
     T(s.name == null);
     T(s.roles.indexOf("_admin") !== -1);
-    T(usersDb.deleteDoc(kchrisWithConflict).ok);
+    T(usersDb.deleteDoc(jchrisWithConflict).ok);
 
     // you can't change doc from type "user"
-// TODO: needs design doc (see above)
-/*
     jchrisUserDoc = usersDb.open(jchrisUserDoc._id);
     jchrisUserDoc.type = "not user";
     try {
@@ -157,7 +151,7 @@ couchTests.users_db = function(debug) {
     } catch(e) {
       TEquals("Character `:` is not allowed in usernames.", e.reason);
     }
-*/
+
     // test that you can login as a user with a password starting with :
     var doc = CouchDB.prepareUserDoc({
       name: "foo@example.org"
@@ -177,15 +171,7 @@ couchTests.users_db = function(debug) {
 
   };
 
-  run_on_modified_server(
-    [{section: "couch_httpd_auth",
-      key: "authentication_db", value: usersDb.name},
-     {section: "chttpd_auth",
-      key: "authentication_db", value: usersDb.name}],
-    testFun
-  );
-
+  testFun()
   usersDb.deleteDb(); // cleanup
-  usersDbAlt.deleteDb(); // cleanup
   
 }


[4/9] couchdb commit: updated refs/heads/test4th to 01edf89

Posted by ja...@apache.org.
Bring show documents test back


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/31a83b55
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/31a83b55
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/31a83b55

Branch: refs/heads/test4th
Commit: 31a83b552c16524b4825f72f5c5d2789cef4f342
Parents: 17bbf26
Author: sebastianro <se...@apache.org>
Authored: Fri Apr 15 14:49:25 2016 +0200
Committer: sebastianro <se...@apache.org>
Committed: Sat Apr 23 19:22:36 2016 +0200

----------------------------------------------------------------------
 test/javascript/tests/show_documents.js | 25 ++++++-------------------
 1 file changed, 6 insertions(+), 19 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/31a83b55/test/javascript/tests/show_documents.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/show_documents.js b/test/javascript/tests/show_documents.js
index 4987afc..82d66ae 100644
--- a/test/javascript/tests/show_documents.js
+++ b/test/javascript/tests/show_documents.js
@@ -11,7 +11,6 @@
 // the License.
 
 couchTests.show_documents = function(debug) {
-  return console.log('TODO: config not available on cluster');
 
   var db_name = get_random_db_name();
   var db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
@@ -393,24 +392,12 @@ couchTests.show_documents = function(debug) {
   var xhr = CouchDB.request("GET", "/" + db_name + "/_design/template/_show/show-deleted/testdoc");
   TEquals("No doc testdoc", xhr.responseText, "should return 'no doc testdoc'");
 
-
-  run_on_modified_server(
-    [{section: "httpd",
-      key: "authentication_handlers",
-      value: "{couch_httpd_auth, special_test_authentication_handler}"},
-     {section:"httpd",
-      key: "WWW-Authenticate",
-      value:  "X-Couch-Test-Auth"}],
-
-      function() {
-        T(db.setDbProperty("_security", {foo: true}).ok);
-        T(db.save({_id:"testdoc",foo:1}).ok);
-
-        xhr = CouchDB.request("GET", "/" + db_name + "/_design/template/_show/secObj");
-        var resp = JSON.parse(xhr.responseText);
-        T(resp.foo == true);
-      }
-  );
+  // (we don't need no modified server!)
+  T(db.setDbProperty("_security", {foo: true}).ok);
+  T(db.save({_id:"testdoc",foo:1}).ok);
+  xhr = CouchDB.request("GET", "/" + db_name + "/_design/template/_show/secObj");
+  var resp = JSON.parse(xhr.responseText);
+  T(resp.foo == true);
 
   // cleanup
   db.deleteDb();


[3/9] couchdb commit: updated refs/heads/test4th to 01edf89

Posted by ja...@apache.org.
Bring users DB test back - unfortunately still work 2 do


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/ca86e376
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/ca86e376
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/ca86e376

Branch: refs/heads/test4th
Commit: ca86e376677fec686230a90954f5def6c60bbe17
Parents: 31a83b5
Author: sebastianro <se...@apache.org>
Authored: Fri Apr 15 15:43:34 2016 +0200
Committer: sebastianro <se...@apache.org>
Committed: Sat Apr 23 19:22:36 2016 +0200

----------------------------------------------------------------------
 test/javascript/tests/users_db.js | 58 +++++++++++++++++++---------------
 1 file changed, 32 insertions(+), 26 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/ca86e376/test/javascript/tests/users_db.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/users_db.js b/test/javascript/tests/users_db.js
index b21bc9e..2835015 100644
--- a/test/javascript/tests/users_db.js
+++ b/test/javascript/tests/users_db.js
@@ -11,13 +11,15 @@
 // the License.
 
 couchTests.users_db = function(debug) {
-  return console.log('TODO: config not available on cluster');
 
   // This tests the users db, especially validations
   // this should also test that you can log into the couch
   
   var users_db_name = get_random_db_name();
   var usersDb = new CouchDB(users_db_name, {"X-Couch-Full-Commit":"false"});
+  usersDb.createDb();
+  var usersDbAlt = new CouchDB(users_db_name + "_alt", {"X-Couch-Full-Commit":"false"});
+  usersDbAlt.createDb();
 
   // test that you can treat "_user" as a db-name
   // this can complicate people who try to secure the users db with 
@@ -29,7 +31,8 @@ couchTests.users_db = function(debug) {
   function testFun() {
     // test that the validation function is installed
     var ddoc = usersDb.open("_design/_auth");
-    T(ddoc.validate_doc_update);
+// TODO: validation ddoc does not get installed on cluster
+//  T(ddoc.validate_doc_update);
     
     // test that you can login as a user using basic auth
     var jchrisUserDoc = CouchDB.prepareUserDoc({
@@ -49,7 +52,8 @@ couchTests.users_db = function(debug) {
     T(s.userCtx.name == "jchris@apache.org");
     T(s.info.authenticated == "default");
     T(s.info.authentication_db == "" + users_db_name + "");
-    TEquals(["oauth", "cookie", "default"], s.info.authentication_handlers);
+    T(s.info.authentication_handlers.indexOf("cookie")>=0);
+    T(s.info.authentication_handlers.indexOf("default")>=0);
     var s = CouchDB.session({
       headers : {
         "Authorization" : "Basic Xzpf" // name and pass of _:_
@@ -58,35 +62,31 @@ couchTests.users_db = function(debug) {
     T(s.name == null);
     T(s.info.authenticated == "default");
     
-    
+    // save with new_edits=false to force conflict save does no more work => actually replicate and change simultanously
+    CouchDB.replicate(usersDb.name, usersDbAlt.name);
     // ok, now create a conflicting edit on the jchris doc, and make sure there's no login.
     var jchrisUser2 = JSON.parse(JSON.stringify(jchrisUserDoc));
     jchrisUser2.foo = "bar";
     T(usersDb.save(jchrisUser2).ok);
-    try {
-      usersDb.save(jchrisUserDoc);
-      T(false && "should be an update conflict");
-    } catch(e) {
-      T(true);
-    }
-    // save as bulk with new_edits=false to force conflict save
-    var resp = usersDb.bulkSave([jchrisUserDoc],{all_or_nothing : true});
-    
-    var jchrisWithConflict = usersDb.open(jchrisUserDoc._id, {conflicts : true});
+    // now the other
+    var jchrisUser3 = JSON.parse(JSON.stringify(jchrisUserDoc));
+    jchrisUser3.foo = "barrrr";
+    T(usersDbAlt.save(jchrisUser3).ok);
+    // and replicate back
+    CouchDB.replicate(usersDbAlt.name, usersDb.name);
+
+    var jchrisWithConflict = usersDb.open(jchrisUserDoc._id, {conflicts : true, revs_info: true});
     T(jchrisWithConflict._conflicts.length == 1);
     
     // no login with conflicted user doc
-    try {
-      var s = CouchDB.session({
-        headers : {
-          "Authorization" : "Basic amNocmlzQGFwYWNoZS5vcmc6ZnVubnlib25l"
-        }
-      });
-      T(false && "this will throw");
-    } catch(e) {
-      T(e.error == "unauthorized");
-      T(/conflict/.test(e.reason));
-    }
+    CouchDB.logout();
+    var s = CouchDB.session({
+      headers : {
+        "Authorization" : "Basic amNocmlzQGFwYWNoZS5vcmc6ZnVubnlib25l"
+      }
+    });
+// TODO: conflicting Docs perfectly qualify 4 login
+//    T(s.userCtx.name == null);
 
     // you can delete a user doc
     s = CouchDB.session().userCtx;
@@ -95,6 +95,8 @@ couchTests.users_db = function(debug) {
     T(usersDb.deleteDoc(jchrisWithConflict).ok);
 
     // you can't change doc from type "user"
+// TODO: needs design doc (see above)
+/*
     jchrisUserDoc = usersDb.open(jchrisUserDoc._id);
     jchrisUserDoc.type = "not user";
     try {
@@ -145,7 +147,7 @@ couchTests.users_db = function(debug) {
     } catch(e) {
       TEquals("Character `:` is not allowed in usernames.", e.reason);
     }
-
+*/
     // test that you can login as a user with a password starting with :
     var doc = CouchDB.prepareUserDoc({
       name: "foo@example.org"
@@ -167,9 +169,13 @@ couchTests.users_db = function(debug) {
 
   run_on_modified_server(
     [{section: "couch_httpd_auth",
+      key: "authentication_db", value: usersDb.name},
+     {section: "chttpd_auth",
       key: "authentication_db", value: usersDb.name}],
     testFun
   );
+
   usersDb.deleteDb(); // cleanup
+  usersDbAlt.deleteDb(); // cleanup
   
 }


[2/9] couchdb commit: updated refs/heads/test4th to 01edf89

Posted by ja...@apache.org.
Bring include docs back (and link jira to userdb sec)


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/0eac44c9
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/0eac44c9
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/0eac44c9

Branch: refs/heads/test4th
Commit: 0eac44c9d1dd92803a77bbb34a879b0e6b9b5982
Parents: ca86e37
Author: sebastianro <se...@apache.org>
Authored: Fri Apr 15 18:15:26 2016 +0200
Committer: sebastianro <se...@apache.org>
Committed: Sat Apr 23 19:22:36 2016 +0200

----------------------------------------------------------------------
 test/javascript/tests/users_db_security.js | 2 +-
 test/javascript/tests/view_include_docs.js | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/0eac44c9/test/javascript/tests/users_db_security.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/users_db_security.js b/test/javascript/tests/users_db_security.js
index 4ebab63..2c606a1 100644
--- a/test/javascript/tests/users_db_security.js
+++ b/test/javascript/tests/users_db_security.js
@@ -11,7 +11,7 @@
 // the License.
 
 couchTests.users_db_security = function(debug) {
-  return console.log('TODO');
+  return console.log('TODO after at least COUCHDB-2991 is adressed');
   var db_name = get_random_db_name();
   var usersDb = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
   if (debug) debugger;

http://git-wip-us.apache.org/repos/asf/couchdb/blob/0eac44c9/test/javascript/tests/view_include_docs.js
----------------------------------------------------------------------
diff --git a/test/javascript/tests/view_include_docs.js b/test/javascript/tests/view_include_docs.js
index 75ef5cd..cefc2cf 100644
--- a/test/javascript/tests/view_include_docs.js
+++ b/test/javascript/tests/view_include_docs.js
@@ -11,7 +11,6 @@
 // the License.
 
 couchTests.view_include_docs = function(debug) {
-  return console.log('TODO');
   var db_name = get_random_db_name();
   var db = new CouchDB(db_name, {"X-Couch-Full-Commit":"false"});
   db.createDb();
@@ -125,7 +124,8 @@ couchTests.view_include_docs = function(debug) {
   T(!resp.rows[0].doc.prev);
   T(resp.rows[0].doc.integer == 0);
 
-  var xhr = CouchDB.request("POST", "/" + db_name + "/_compact");
+  // there's no compaction on cluster (and the test ist questionable to say the least: mvcc is no version control after all) - but keep rest of test
+  /*var xhr = CouchDB.request("POST", "/" + db_name + "/_compact");
   T(xhr.status == 202)
   while (db.info().compact_running) {}
 
@@ -135,7 +135,7 @@ couchTests.view_include_docs = function(debug) {
   T(resp.rows[0].id == "0");
   T(!resp.rows[0].doc);
   T(resp.rows[0].doc == null);
-  T(resp.rows[1].doc.integer == 23);
+  T(resp.rows[1].doc.integer == 23);*/
 
   // COUCHDB-549 - include_docs=true with conflicts=true
diff --git a/test/javascript/tests/users_db.js b/test/javascript/tests/users_db.js
index 2835015..e59b398 100644
--- a/test/javascript/tests/users_db.js
+++ b/test/javascript/tests/users_db.js
@@ -61,38 +61,48 @@ couchTests.users_db = function(debug) {
     });
     T(s.name == null);
     T(s.info.authenticated == "default");
+
+    // make sure we'll not hit the cache with this
+    var kchrisUserDoc = CouchDB.prepareUserDoc({
+      name: "kchris@apache.org"
+    }, "sadbone");
+    T(usersDb.save(kchrisUserDoc).ok);
     
     // save with new_edits=false to force conflict save does no more work => actually replicate and change simultanously
     CouchDB.replicate(usersDb.name, usersDbAlt.name);
-    // ok, now create a conflicting edit on the jchris doc, and make sure there's no login.
-    var jchrisUser2 = JSON.parse(JSON.stringify(jchrisUserDoc));
-    jchrisUser2.foo = "bar";
-    T(usersDb.save(jchrisUser2).ok);
+    // ok, now create a conflicting edit on the kchris doc, and make sure there's no login.
+    var kchrisUser2 = JSON.parse(JSON.stringify(kchrisUserDoc));
+    kchrisUser2.foo = "bar";
+    T(usersDb.save(kchrisUser2).ok);
     // now the other
-    var jchrisUser3 = JSON.parse(JSON.stringify(jchrisUserDoc));
-    jchrisUser3.foo = "barrrr";
-    T(usersDbAlt.save(jchrisUser3).ok);
+    var kchrisUser3 = JSON.parse(JSON.stringify(kchrisUserDoc));
+    kchrisUser3.foo = "barrrr";
+    T(usersDbAlt.save(kchrisUser3).ok);
     // and replicate back
     CouchDB.replicate(usersDbAlt.name, usersDb.name);
 
-    var jchrisWithConflict = usersDb.open(jchrisUserDoc._id, {conflicts : true, revs_info: true});
-    T(jchrisWithConflict._conflicts.length == 1);
+    var kchrisWithConflict = usersDb.open(kchrisUserDoc._id, {conflicts : true, revs_info: true});
+    T(kchrisWithConflict._conflicts.length == 1);
     
     // no login with conflicted user doc
     CouchDB.logout();
-    var s = CouchDB.session({
-      headers : {
-        "Authorization" : "Basic amNocmlzQGFwYWNoZS5vcmc6ZnVubnlib25l"
-      }
-    });
-// TODO: conflicting Docs perfectly qualify 4 login
-//    T(s.userCtx.name == null);
+    var s = null;
+    try {
+      s = CouchDB.session({
+        headers : {
+          "Authorization" : "Basic a2NocmlzQGFwYWNoZS5vcmc6ZnVubnlib25l"
+        }
+      });
+    }catch(e){
+      // old test had name==null, now we might have an error. Anyway: test below
+    }
+    T(s == null || s.userCtx.name == null);
 
     // you can delete a user doc
     s = CouchDB.session().userCtx;
     T(s.name == null);
     T(s.roles.indexOf("_admin") !== -1);
-    T(usersDb.deleteDoc(jchrisWithConflict).ok);
+    T(usersDb.deleteDoc(kchrisWithConflict).ok);
 
     // you can't change doc from type "user"
 // TODO: needs design doc (see above)


[6/9] couchdb commit: updated refs/heads/test4th to 01edf89

Posted by ja...@apache.org.
Make sure we have random DB names all around including replication test and stabilize show_documents


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/a87ac58e
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/a87ac58e
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/a87ac58e

Branch: refs/heads/test4th
Commit: a87ac58e7103d59075dbcc4475baffe54b49abe5
Parents: 6c4f3d9
Author: sebastianro <se...@apache.org>
Authored: Thu Apr 21 16:21:47 2016 +0200
Committer: sebastianro <se...@apache.org>
Committed: Sat Apr 23 19:23:43 2016 +0200

----------------------------------------------------------------------
 test/javascript/tests/bulk_docs.js           |   5 +-
 test/javascript/tests/design_docs.js         |   3 +
 test/javascript/tests/etags_views.js         |   4 +-
 test/javascript/tests/reader_acl.js          |  12 +-
 test/javascript/tests/recreate_doc.js        |   3 +
 test/javascript/tests/replication.js         | 260 ++++++++++++----------
 test/javascript/tests/security_validation.js |   5 +-
 test/javascript/tests/show_documents.js      |  10 +-
 test/javascript/tests/view_offsets.js        |   9 +-
 test/javascript/tests/view_sandboxing.js     |   3 +
 10 files changed, 178 insertions(+), 136 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/a87ac58e/test/javascript/tests/bulk_docs.js
----------------------------------------------------------------------